aboutsummaryrefslogtreecommitdiff
path: root/graphics/sjis.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'graphics/sjis.cpp')
-rw-r--r--graphics/sjis.cpp18
1 files changed, 10 insertions, 8 deletions
diff --git a/graphics/sjis.cpp b/graphics/sjis.cpp
index d46ac3e965..589e27fd43 100644
--- a/graphics/sjis.cpp
+++ b/graphics/sjis.cpp
@@ -31,17 +31,19 @@
namespace Graphics {
-FontSJIS *FontSJIS::createFont() {
+FontSJIS *FontSJIS::createFont(const Common::Platform platform) {
FontSJIS *ret = 0;
- // First try ScummVM's font.
- ret = new FontSjisSVM();
- if (ret && ret->loadData())
- return ret;
- delete ret;
+ // Try the font ROM of the specified platform
+ if (platform == Common::kPlatformFMTowns) {
+ ret = new FontTowns();
+ if (ret && ret->loadData())
+ return ret;
+ delete ret;
+ }
- // Next try the FM-Towns font ROM.
- ret = new FontTowns();
+ // Try ScummVM's font.
+ ret = new FontSjisSVM();
if (ret && ret->loadData())
return ret;
delete ret;